@@ -14,9 +14,4 @@ If you use this code, please cite the following paper:
     year = "2021",
     pages = "167--174",
 }
-'''
-import open_intent_detection.run as detection
-import open_intent_discovery.run as discovery
-if __name__ == '__main__':
-    detection()
-    discovery()
\ No newline at end of file
+'''
\ No newline at end of file
